==> easy-antd-modal-1.4.0.tgz: package/lib/drag-modal/BaseModal.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/drag-modal/BaseModal.tsx
var BaseModal_exports = {};
__export(BaseModal_exports, {
  default: () => BaseModal_default
});
module.exports = __toCommonJS(BaseModal_exports);
var import_core = require("@dnd-kit/core");
var import_utilities = require("@dnd-kit/utilities");
var import_modal = __toESM(require("../modal"));
function BaseModal(props) {
  const { modalRender, title, offsetX, offsetY, ...resetProps } = props;
  const { attributes, isDragging, listeners, setNodeRef, transform } = (0, import_core.useDraggable)({
    id: "easy-antd-modal-draggable-modal"
  });
  const mergeModalRender = (rawNode) => /* @__PURE__ */ React.createElement(
    "div",
    {
      ref: setNodeRef,
      style: {
        position: "relative",
        transform: isDragging ? import_utilities.CSS.Transform.toString(transform) : void 0,
        top: offsetY,
        left: offsetX
      }
    },
    (modalRender == null ? void 0 : modalRender(rawNode)) ?? rawNode
  );
  return /* @__PURE__ */ React.createElement(
    import_modal.default,
    {
      title: /* @__PURE__ */ React.createElement("div", { ...listeners, ...attributes, style: { cursor: "move" } }, title),
      modalRender: mergeModalRender,
      ...resetProps
    }
  );
}
var BaseModal_default = BaseModal;

==> easy-antd-modal-1.4.1.tgz: package/lib/drag-modal/BaseModal.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/drag-modal/BaseModal.tsx
var BaseModal_exports = {};
__export(BaseModal_exports, {
  default: () => BaseModal_default
});
module.exports = __toCommonJS(BaseModal_exports);
var import_core = require("@dnd-kit/core");
var import_utilities = require("@dnd-kit/utilities");
var import_usePrefixCls = __toESM(require("../hooks/usePrefixCls"));
var import_modal = __toESM(require("../modal"));
function BaseModal(props) {
  const { modalRender, title, offsetX, offsetY, className, ...resetProps } = props;
  const prefixCls = (0, import_usePrefixCls.default)("drag-modal", props.prefixCls);
  const { attributes, isDragging, listeners, setNodeRef, transform } = (0, import_core.useDraggable)({
    id: "easy-antd-modal-draggable-modal"
  });
  const mergeModalRender = (rawNode) => /* @__PURE__ */ React.createElement(
    "div",
    {
      ref: setNodeRef,
      style: {
        position: "relative",
        transform: isDragging ? import_utilities.CSS.Transform.toString(transform) : void 0,
        top: offsetY,
        left: offsetX
      },
      className: `${prefixCls}-content__wrapper`
    },
    (modalRender == null ? void 0 : modalRender(rawNode)) ?? rawNode
  );
  const modalCls = [className, isDragging && `${prefixCls}_dragging`].filter(Boolean).join(" ");
  return /* @__PURE__ */ React.createElement(
    import_modal.default,
    {
      ...resetProps,
      prefixCls,
      className: modalCls,
      title: /* @__PURE__ */ React.createElement(
        "div",
        {
          ...listeners,
          ...attributes,
          style: { cursor: "move" },
          className: `${prefixCls}-title__inner`
        },
        title
      ),
      modalRender: mergeModalRender
    }
  );
}
var BaseModal_default = BaseModal;
